package com.fzm.common.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import cn.fzm.chain.simplesdk.client.ParaChainClient;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.RandomUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fzm.common.constant.RedisConstant;
import com.fzm.common.constant.SystemConstant;
import com.fzm.common.entity.Category;
import com.fzm.common.entity.Nft;
import com.fzm.common.entity.User;
import com.fzm.common.entity.vo.CollectionNftVo;
import com.fzm.common.enums.ResultCode;
import com.fzm.common.exception.GlobalException;
import com.fzm.common.mapper.NftMapper;
import com.fzm.common.service.CategoryService;
import com.fzm.common.service.NftService;
import com.fzm.common.service.UserService;
import com.fzm.common.utils.JsonUtil;
import com.fzm.common.utils.RedisUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author tangtuo
 * @date 2021/6/30 15:55
 */
@Service
@Transactional(rollbackFor = RuntimeException.class)
public class NftServiceImpl extends ServiceImpl<NftMapper, Nft> implements NftService {

    @Resource
    private ParaChainClient paraChainClient;

    @Resource
    RedisUtil redisUtil;

    @Resource
    private UserService userService;

    @Resource
    private NftMapper nftMapper;

    @Resource
    private CategoryService categoryService;

    @Value("${chain.para.contract-name}")
    private String contractName;

    @Override
    public Nft publish(Nft nft) {
        User user = userService.getById(StpUtil.getLoginIdAsInt());
        // 如果用户是第一次发行作品,把用户的isPublish修改成1
        if (SystemConstant.BOOLEAN_DATA_FALSE.equals(user.getIsPublish())) {
            User u = new User().setId(user.getId()).setIsPublish(SystemConstant.BOOLEAN_DATA_TRUE);
            userService.updateById(u);
        }
        // 获取用户的私钥
        String wallet = user.getWallet();
        String privkey = paraChainClient.walletDumpPrivkey(wallet);
        String txHash = paraChainClient.evmPublishNFT1155(contractName, wallet, privkey, 1, true);
        if (StringUtils.isBlank(txHash) || !txHash.contains("-")) {
            throw GlobalException.newException(ResultCode.FAILED, "nft发行失败");
        }
        String[] split = txHash.split("-");
        nft.setNftHash(split[0]);
        nft.setTokenId(split[1]);
        nft.setPublishTime(new Date());
        save(nft);
        return getById(nft.getId());
    }

    @Override
    public List<Nft> list(Integer pageNum, Integer pageSize, Integer categoryId) {
        return nftMapper.list(pageNum, pageSize, categoryId);
    }

    @Override
    public Boolean collection(Integer id) {
        String key = RedisConstant.COLLECTION_USER_PREFIX + StpUtil.getLoginIdAsInt();
        // 如果用户收藏的nft已经存在列表里,那么就是取消收藏
        if (redisUtil.sIsMember(key, id.toString())) {
            return redisUtil.sRemove(key, id.toString()) == 1;
        } else {
            return redisUtil.sAdd(key, id.toString()) == 1;
        }
    }


    @Override
    public List<CollectionNftVo> getCollectionList() {
        String key = RedisConstant.COLLECTION_USER_PREFIX + StpUtil.getLoginIdAsInt();
        Set<String> set = redisUtil.setMembers(key);
        if (CollectionUtil.isEmpty(set)) {
            return new ArrayList<>();
        }
        List<Integer> ids = set.stream().map(Integer::valueOf).collect(Collectors.toList());
        return nftMapper.getCollectionList(ids);
    }

    @Override
    public List<Nft> listCurrent(Integer categoryId, Integer userId) {
        QueryWrapper<Nft> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status", SystemConstant.BOOLEAN_DATA_TRUE).eq("user_id", userId);
        if (categoryId != null) {
            queryWrapper.eq("category_id", categoryId);
        }
        queryWrapper.orderByDesc("is_top", "publish_time");
        return nftMapper.selectList(queryWrapper);
    }

    @Override
    public String generateNftId(Integer categoryId) {
        Category category = categoryService.getCategoryById(categoryId);
        if (category == null) {
            throw GlobalException.newException(ResultCode.DATA_ERROR, "没找到此类目");
        }
        int code = RandomUtil.randomInt(1000, 10000);
        return String.format("JOYING-%s-%s%s", category.getEnglishName(), System.currentTimeMillis(), code);
    }

    public static void main(String[] args) {
        int code = RandomUtil.randomInt(1000, 10000);
        System.out.println(String.format("JOYING-%s-%s%s", "SCRIPT", System.currentTimeMillis(), code));
    }
}
