package com.fzm.common.utils;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.IdUtil;
import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.aliyun.oss.model.*;
import com.fzm.common.properties.OssProperties;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.Date;

/**
 * @author tangtuo
 * @date 2021/6/29 16:07
 */
@Component
public class OssUtil {

    @Resource
    private OssProperties ossProperties;

    @Resource
    private HttpServletResponse response;

    /**
     * @param file
     * @return
     */
    public String putObject(MultipartFile file, String bucket) throws IOException {
        String endpoint = ossProperties.getEndPoint();
        // 阿里云主账号AccessKey拥有所有API的访问权限，风险很高。强烈建议您创建并使用RAM账号进行API访问或日常运维，请登录RAM控制台创建RAM账号。
        String accessKeyId = ossProperties.getAppKey();
        String accessKeySecret = ossProperties.getAppSecret();
        // <yourObjectName>上传文件到OSS时需要指定包含文件后缀在内的完整路径，例如20210629/a8703bcf7d354ea2bbb5ccdf76b7405f/123.jpg。
        String objectName = String.format("%s/%s/%s", DateUtil.format(new Date(), "yyyyMMdd"), IdUtil.simpleUUID(), file.getOriginalFilename());

        // 创建OSSClient实例。
        OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);
        ossClient.putObject(bucket, objectName, file.getInputStream());

        // 关闭OSSClient。
        ossClient.shutdown();
        return String.format("https://%s.%s/%s", bucket, endpoint, objectName);
    }

    /**
     * 文件普通存储
     *
     * @param file
     * @return
     * @throws IOException
     */
    public String putSimpleObject(MultipartFile file) throws IOException {
        return putObject(file, ossProperties.getSimpleBucket());
    }

    /**
     * 文件加密存储
     *
     * @param file
     * @return
     * @throws IOException
     */
    public String putEncryptObject(MultipartFile file) throws IOException {
        return putObject(file, ossProperties.getEncryptBucket());
    }

    public void createEncryptBucket() {
        String endpoint = ossProperties.getEndPoint();
        // 阿里云主账号AccessKey拥有所有API的访问权限，风险很高。强烈建议您创建并使用RAM账号进行API访问或日常运维，请登录RAM控制台创建RAM账号。
        String accessKeyId = ossProperties.getAppKey();
        String accessKeySecret = ossProperties.getAppSecret();
        OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);

        // 创建存储空间。
        String bucket = ossProperties.getEncryptBucket();
        if (!ossClient.doesBucketExist(bucket)) {
            // 设置Bucket加密。
            ServerSideEncryptionByDefault applyServerSideEncryptionByDefault = new ServerSideEncryptionByDefault(SSEAlgorithm.AES256);
            ServerSideEncryptionConfiguration sseConfig = new ServerSideEncryptionConfiguration();
            sseConfig.setApplyServerSideEncryptionByDefault(applyServerSideEncryptionByDefault);
            SetBucketEncryptionRequest request = new SetBucketEncryptionRequest("<yourBucketName>", sseConfig);
            ossClient.setBucketEncryption(request);
            ossClient.shutdown();
            ossClient.createBucket(bucket);
        }
        ossClient.createBucket(ossProperties.getEncryptBucket());
    }


    /**
     * 下载文件
     *
     * @param file
     */
    public void downloadFile(String file) {
        String endpoint = ossProperties.getEndPoint();
        // 阿里云主账号AccessKey拥有所有API的访问权限，风险很高。强烈建议您创建并使用RAM账号进行API访问或日常运维，请登录RAM控制台创建RAM账号。
        String accessKeyId = ossProperties.getAppKey();
        String accessKeySecret = ossProperties.getAppSecret();
        String bucketName = ossProperties.getEncryptBucket();

        // 创建OSSClient实例。
        OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);
        // ossObject包含文件所在的存储空间名称、文件名称、文件元信息以及一个输入流。
        file = file.replace(String.format("https://%s.%s/", bucketName, endpoint), "");
        OSSObject ossObject = ossClient.getObject(bucketName, file);
        try {
            // 读取文件内容。
            InputStream inputStream = ossObject.getObjectContent();
            BufferedInputStream in = new BufferedInputStream(inputStream);// 把输入流放入缓存流
            ServletOutputStream outputStream = response.getOutputStream();
            BufferedOutputStream out = new BufferedOutputStream(outputStream);// 把输出流放入缓存流
            byte[] buffer = new byte[1024];
            int len = 0;
            while ((len = in.read(buffer)) != -1) {
                out.write(buffer, 0, len);
            }
            if (out != null) {
                out.flush();
                out.close();
            }
            if (in != null) {
                in.close();
            }

        } catch (Exception e) {
            e.printStackTrace();
        }

    }


    public static void main(String[] args) {
        String endpoint = "oss-cn-hangzhou.aliyuncs.com";
        // 阿里云主账号AccessKey拥有所有API的访问权限，风险很高。强烈建议您创建并使用RAM账号进行API访问或日常运维，请登录RAM控制台创建RAM账号。
        String accessKeyId = "LTAI5tHGn7cVJdEtihTFLSeB";
        String accessKeySecret = "XYmfBSbLaZoblGXZwIXkbhfBD7a1eg";
        OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);

        // 创建存储空间。
        String bucket = "test-nft-2";
        if (!ossClient.doesBucketExist(bucket)) {
            // 设置Bucket加密。
            ServerSideEncryptionByDefault applyServerSideEncryptionByDefault = new ServerSideEncryptionByDefault(SSEAlgorithm.AES256);
            ServerSideEncryptionConfiguration sseConfig = new ServerSideEncryptionConfiguration();
            sseConfig.setApplyServerSideEncryptionByDefault(applyServerSideEncryptionByDefault);
            SetBucketEncryptionRequest request = new SetBucketEncryptionRequest(bucket, sseConfig);
            ossClient.setBucketEncryption(request);
            ossClient.shutdown();
        }
    }
}
