package com.fzm.portal.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.crypto.SecureUtil;
import com.fzm.common.constant.SystemConstant;
import com.fzm.common.entity.Category;
import com.fzm.common.entity.Nft;
import com.fzm.common.entity.User;
import com.fzm.common.entity.vo.CollectionNftVo;
import com.fzm.common.entity.vo.NftVo;
import com.fzm.common.enums.ResultCode;
import com.fzm.common.exception.GlobalException;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.service.CategoryService;
import com.fzm.common.service.NftService;
import com.fzm.common.service.UserService;
import com.fzm.common.utils.OssUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author tangtuo
 * @date 2021/6/30 15:08
 */
@RestController
@RequestMapping(value = "/nft")
@Api(tags = "nft管理")
public class NftController {

    @Resource
    private OssUtil ossUtil;

    @Resource
    private NftService nftService;

    @Resource
    private UserService userService;

    @Resource
    private CategoryService categoryService;


    @SaCheckLogin
    @PostMapping("/publish")
    @ApiOperation(value = "nft发行")
    public ResponseModel<Nft> publish(@ApiParam(value = "类目id", required = true) Integer categoryId,
                                      @ApiParam(value = "名称", required = true) String name,
                                      @ApiParam(value = "作者", required = true) String author,
                                      @ApiParam(value = "主题", required = true) String theme,
                                      @ApiParam(value = "简介", required = true) String synopsis,
                                      @ApiParam(value = "文件", required = false) MultipartFile file,
                                      @ApiParam(value = "文件hash", required = true) String fileHash,
                                      @ApiParam(value = "平台存档  0-不存档  1-加密存档", required = true) Integer isArchives,
                                      @ApiParam(value = "授权阅读  0-不需要授权  1-需要授权", required = false) Integer isGrant,
                                      @ApiParam(value = "nft编号", required = true) String nftId) throws IOException {
        Nft nft = new Nft();
        // 当平台存档选择加密存档时,文件必传
        if (SystemConstant.BOOLEAN_DATA_TRUE.equals(isArchives)) {
            if (file == null || isGrant == null) {
                throw GlobalException.newException(ResultCode.VALIDATE_FAILED, "当选择加密存档的时候,文件和授权阅读不能为空");
            }
            String fileUrl = ossUtil.putEncryptObject(file);
            nft.setFileUrl(fileUrl).setIsGrant(isGrant).setFileName(file.getOriginalFilename());
        }
        nft.setCategoryId(categoryId)
                .setUserId(StpUtil.getLoginIdAsInt())
                .setName(name)
                .setAuthor(author)
                .setTheme(theme)
                .setSynopsis(synopsis)
                .setFileHash(fileHash)
                .setNftId(nftId)
                .setIsArchives(isArchives);
        return ResponseModel.success(nftService.publish(nft));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取nft列表")
    public ResponseModel list(@ApiParam(value = "当前页码") @RequestParam Integer pageNum,
                              @ApiParam(value = "每页记录数") @RequestParam Integer pageSize,
                              @ApiParam(value = "类目id,查询所有的时候传null") @RequestParam(required = false) Integer categoryId) {

        pageNum = (pageNum - 1) * pageSize;
        List<Nft> list = nftService.list(pageNum, pageSize, categoryId);
        return ResponseModel.success(list);
    }

    @GetMapping("get/{id}")
    @ApiOperation(value = "获取nft详情")
    public ResponseModel<NftVo> getById(@PathVariable Integer id) {
        Nft nft = nftService.getById(id);
        if (nft == null) {
            throw GlobalException.newException(ResultCode.DATA_ERROR, "没找到此nft的详情");
        }
        User user = userService.getById(nft.getUserId());
        if (user == null) {
            throw GlobalException.newException(ResultCode.DATA_ERROR, "没找到此nft的发布人的信息");
        }
        return ResponseModel.success(new NftVo(nft, user));
    }

    @SaCheckLogin
    @GetMapping("/list/current")
    @ApiOperation(value = "获取我的nft列表")
    public ResponseModel<Map<String, Object>> listCurrent(@ApiParam(value = "类目id,查询全部的时候传null") @RequestParam(required = false) Integer categoryId) {
        List<Nft> list = nftService.listCurrent(categoryId, StpUtil.getLoginIdAsInt());
        List<CollectionNftVo> nftVoList = list.stream()
                .map(nft -> new CollectionNftVo(nft, categoryService.getCategoryById(nft.getCategoryId())))
                .collect(Collectors.toList());
        HashMap<String, Object> result = new HashMap<>(4);
        result.put("list", nftVoList);
        result.put("size", nftVoList.size());
        return ResponseModel.success(result);
    }

    @SaCheckLogin
    @GetMapping("/generateNftId")
    @ApiOperation(value = "生成nft编号")
    public ResponseModel<String> generateNftId(@ApiParam(value = "类目id", required = true) @RequestParam Integer categoryId) {
        String nftId = nftService.generateNftId(categoryId);
        return ResponseModel.success(nftId);
    }

    @SaCheckLogin
    @PostMapping("/file/md5")
    @ApiOperation(value = "获取文件的md5值")
    public ResponseModel<String> getFileMd5Value(MultipartFile file) throws IOException {
        String md5 = SecureUtil.md5(file.getInputStream());
        return ResponseModel.success(md5);
    }


}
