SET NAMES utf8mb4;
SET
FOREIGN_KEY_CHECKS = 0;

DROP TABLE IF EXISTS `tb_auth_enterprise`;
CREATE TABLE `tb_auth_enterprise`
(
    `id`                    int(11) NOT NULL AUTO_INCREMENT,
    `user_id`               int(11) NOT NULL COMMENT '用户id',
    `enterprise_name`       varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '企业名称',
    `uscc`                  varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '统一社会信用代码',
    `legal_person_name`     varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '法人姓名',
    `legal_person_card_num` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '法人证件号码',
    `mobile`                varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '法人代表手机号码',
    `public_account`        varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '对公账户',
    `bank_name`             varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '开户银行',
    `bank_branch`           varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '开户支行',
    `create_date`           datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_date`           datetime(0) NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP (0),
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `idx_userid`(`user_id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '企业认证信息表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for tb_auth_person
-- ----------------------------
DROP TABLE IF EXISTS `tb_auth_person`;
CREATE TABLE `tb_auth_person`
(
    `id`                 int(11) NOT NULL AUTO_INCREMENT,
    `user_id`            int(11) NULL DEFAULT NULL COMMENT '用户id',
    `name`               varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci   NOT NULL DEFAULT '' COMMENT '姓名',
    `id_card`            varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '身份证号码',
    `card_picture_front` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '身份证正面照片(人脸面)',
    `card_picture_back`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '身份证反面照片(国徽面)',
    `create_date`        datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_date`        datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP (0),
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `idx_userid`(`user_id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 2 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '个人认证信息表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for tb_category
-- ----------------------------
DROP TABLE IF EXISTS `tb_category`;
CREATE TABLE `tb_category`
(
    `id`            int(11) NOT NULL AUTO_INCREMENT,
    `category_name` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '',
    `english_name`  varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
    `create_date`   datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_date`   datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP (0),
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 8 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '首页类目表' ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for tb_nft
-- ----------------------------
DROP TABLE IF EXISTS `tb_nft`;
CREATE TABLE `tb_nft`
(
    `id`           int(11) NOT NULL AUTO_INCREMENT,
    `category_id`  int(11) NOT NULL COMMENT '类目id',
    `user_id`      int(11) NOT NULL COMMENT '用户id',
    `name`         varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '名称',
    `author`       varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL COMMENT '作者',
    `theme`        varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '题材',
    `synopsis`     text CHARACTER SET utf8 COLLATE utf8_general_ci NULL COMMENT '简介',
    `file_name`    varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '文件名',
    `file_url`     varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '文件地址--用户选择不存档的情况下为空',
    `file_hash`    varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '文件上链hash',
    `is_archives`  tinyint(1) NOT NULL COMMENT '平台存档  0-不存档  1-加密存档',
    `is_grant`     tinyint(1) NOT NULL COMMENT '授权阅读  0-不需要授权  1-需要授权',
    `nft_id`       varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL COMMENT 'nft编号',
    `nft_hash`     varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'nft哈希',
    `publish_time` datetime(0) NULL DEFAULT NULL COMMENT 'nft发行时间',
    `is_top`       tinyint(1) NOT NULL DEFAULT 0 COMMENT '是否置顶  0-否  1-是',
    `status`       tinyint(1) NOT NULL DEFAULT 0 COMMENT '0: 下架   1:上架',
    `create_date`  datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_date`  datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP (0),
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for tb_user
-- ----------------------------
DROP TABLE IF EXISTS `tb_user`;
CREATE TABLE `tb_user`
(
    `id`          int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
    `telephone`   varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '手机号',
    `email`       varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '邮箱',
    `password`    varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '密码',
    `wallet`      varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '钱包地址',
    `nickname`    varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '昵称',
    `signature`   varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '个性签名',
    `avatar`      varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '头像',
    `auth_type`   tinyint(1) NULL DEFAULT NULL COMMENT '认证类型  0-个人认证  1-企业认证',
    `auth_status` tinyint(1) NOT NULL DEFAULT 0 COMMENT '实名认证状态  0-未认证  1-认证成功  2-认证失败 3-认证中',
    `create_date` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_date` datetime(0) NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP (0),
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `idx_telephone`(`telephone`) USING BTREE,
    UNIQUE INDEX `idx_email`(`email`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 10 CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '门户用户表' ROW_FORMAT = Dynamic;

SET
FOREIGN_KEY_CHECKS = 1;